==> ux-reward-wrap-3.1.6.tgz: package/lib/components/pageBuilder/ElementCollection/RewardWrap/Rewarded/index.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import * as React from 'react';
import './rewarded.css';
import Filter from '../../../../../components/common/componentTagFilter';
import RewardedList from './RewardedList';
import { takerCloud, getToUserId, getUserInfo } from '../../../../../helper';
import { getCloudApiUrl } from '../../../../../helper/getCloudApi';
import Nodata from '../../../../../components/common/noDataView';

function GoReward(_ref) {
  var handleGoReward = _ref.handleGoReward;
  var dataUdc = encodeURIComponent(JSON.stringify({
    ext: {
      type: 'reward',
      data: 'rewardwrap'
    }
  }));
  return React.createElement("span", {
    className: 'go-reward',
    "data-udc": dataUdc,
    onClick: function onClick() {
      handleGoReward();
    }
  }, "\u5C1D\u8BD5\u6253\u8D4F");
}

var isSelf = function isSelf() {
  var userInfo = getUserInfo();
  var userId = userInfo.Id;
  var toUserId = getToUserId();
  return userId == toUserId;
};

var RewardWrap =
/*#__PURE__*/
function (_React$Component) {
  _inherits(RewardWrap, _React$Component);

  function RewardWrap() {
    var _this;

    _classCallCheck(this, RewardWrap);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(RewardWrap).apply(this, arguments));
    _this.state = {
      selectedFilter: 0,
      rewardedFilter: ['全部']
    };

    _this.genFilter = function () {
      var url = getCloudApiUrl("/UPaaSCoreMRest/100000/ProfileAuthority/HasSamelevelOrSubordinates?bizUserId=".concat(getToUserId()));
      takerCloud(url).then(function (res) {
        if (res.Code == 200) {
          var filter = ['全部'];
          var filterSetting = res.OperationObject || []; //第一个是同级、第二个是下级

          filterSetting.map(function (item, index) {
            if (index == 0 && item) {
              if (isSelf()) {
                filter.push('我的同级');
              } else {
                filter.push('ta的同级');
              }
            }

            if (index == 1 && item) {
              if (isSelf()) {
                filter.push('我的下级');
              } else {
                filter.push('ta的下级');
              }
            }
          });
          filter = filter.length == 1 ? [] : filter;

          _this.setState({
            rewardedFilter: filter
          });
        }
      });
    };

    _this.getData = function (k) {
      var url = getCloudApiUrl("/UPaaSCoreMRest/100000/Reward/GetLatestReward?scope=".concat(k));
      takerCloud(url).then(function (res) {
        if (res.OperationResult) {
          _this.setState({
            rewardedDatas: res.OperationObject
          });
        }
      });
    };

    _this.handleFilter = function (k) {
      var correctVal = k;

      if (k !== 0) {
        correctVal = _this.state.rewardedFilter[k].indexOf('同级') !== -1 ? 1 : 2;
      }

      _this.getData(correctVal);

      _this.setState({
        selectedFilter: k
      });
    };

    return _this;
  }

  _createClass(RewardWrap, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.getData(0);
      this.genFilter();
    }
  }, {
    key: "render",
    value: function render() {
      var _this$state = this.state,
          selectedFilter = _this$state.selectedFilter,
          rewardedDatas = _this$state.rewardedDatas,
          rewardedFilter = _this$state.rewardedFilter;
      var goReward = this.props.goReward;
      if (selectedFilter == 0 && (!rewardedDatas || !rewardedDatas.length)) return React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Nodata, {
        icon: 1,
        text: "\u6682\u65E0\u5458\u5DE5\u83B7\u5F97\u6253\u8D4F"
      }), React.createElement(GoReward, {
        handleGoReward: goReward
      }));
      return React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Filter, {
        tagData: rewardedFilter,
        handleClick: this.handleFilter,
        selectexIndex: selectedFilter
      }), rewardedDatas && rewardedDatas.length ? React.createElement(RewardedList, {
        rewardedData: rewardedDatas,
        goReward: goReward
      }) : React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Nodata, {
        icon: 1,
        text: "\u6682\u65E0\u5458\u5DE5\u83B7\u5F97\u6253\u8D4F"
      }), React.createElement(GoReward, {
        handleGoReward: goReward
      })));
    }
  }]);

  return RewardWrap;
}(React.Component);

export { RewardWrap as default };

==> ux-reward-wrap-3.1.7.tgz: package/lib/components/pageBuilder/ElementCollection/RewardWrap/Rewarded/index.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import * as React from 'react';
import './rewarded.css';
import Filter from '../../../../../components/common/componentTagFilter';
import RewardedList from './RewardedList';
import { takerCloud, getToUserId, getUserInfo } from '../../../../../helper';
import { getCloudApiUrl } from '../../../../../helper/getCloudApi';
import Nodata from '../../../../../components/common/noDataView';

function GoReward(_ref) {
  var handleGoReward = _ref.handleGoReward;
  var dataUdc = encodeURIComponent(JSON.stringify({
    ext: {
      type: 'reward',
      data: 'rewardwrap'
    }
  }));
  return React.createElement("span", {
    className: 'go-reward',
    "data-udc": dataUdc,
    onClick: function onClick() {
      handleGoReward();
    }
  }, "\u5C1D\u8BD5\u6253\u8D4F");
}

var isSelf = function isSelf() {
  var userInfo = getUserInfo();
  var userId = userInfo.Id;
  var toUserId = getToUserId();
  return userId == toUserId;
};

var RewardWrap =
/*#__PURE__*/
function (_React$Component) {
  _inherits(RewardWrap, _React$Component);

  function RewardWrap() {
    var _this;

    _classCallCheck(this, RewardWrap);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(RewardWrap).apply(this, arguments));
    _this.state = {
      selectedFilter: 0,
      rewardedFilter: ['全部']
    };

    _this.genFilter = function () {
      var url = getCloudApiUrl("/UPaaSCoreMRest/100000/ProfileAuthority/HasSamelevelOrSubordinates?bizUserId=".concat(getToUserId()));
      takerCloud(url).then(function (res) {
        if (res.Code == 200) {
          var filter = ['全部'];
          var filterSetting = res.OperationObject || []; //第一个是同级、第二个是下级

          filterSetting.map(function (item, index) {
            if (index == 0 && item) {
              if (isSelf()) {
                filter.push('我的同级');
              } else {
                filter.push('ta的同级');
              }
            }

            if (index == 1 && item) {
              if (isSelf()) {
                filter.push('我的下级');
              } else {
                filter.push('ta的下级');
              }
            }
          });
          filter = filter.length == 1 ? [] : filter;

          _this.setState({
            rewardedFilter: filter
          });
        }
      });
    };

    _this.getData = function (k) {
      var url = getCloudApiUrl("/UPaaSCoreMRest/100000/Reward/GetLatestReward?scope=".concat(k));
      takerCloud(url).then(function (res) {
        if (res.OperationResult) {
          _this.setState({
            rewardedDatas: res.OperationObject
          });
        }
      });
    };

    _this.handleFilter = function (k) {
      var correctVal = k;

      if (k !== 0) {
        correctVal = _this.state.rewardedFilter[k].indexOf('同级') !== -1 ? 1 : 2;
      }

      _this.getData(correctVal);

      _this.setState({
        selectedFilter: k
      });
    };

    return _this;
  }

  _createClass(RewardWrap, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.getData(0);
      this.genFilter();
    }
  }, {
    key: "render",
    value: function render() {
      var _this$state = this.state,
          selectedFilter = _this$state.selectedFilter,
          rewardedDatas = _this$state.rewardedDatas,
          rewardedFilter = _this$state.rewardedFilter;
      var goReward = this.props.goReward;
      var hasFilter = rewardedFilter.length > 10;
      if (selectedFilter == 0 && (!rewardedDatas || !rewardedDatas.length)) return React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Nodata, {
        icon: 1,
        text: "\u6682\u65E0\u5458\u5DE5\u83B7\u5F97\u6253\u8D4F"
      }), React.createElement(GoReward, {
        handleGoReward: goReward
      }));
      return React.createElement("div", {
        className: 'rewarded'
      }, hasFilter && React.createElement(Filter, {
        tagData: rewardedFilter,
        handleClick: this.handleFilter,
        selectexIndex: selectedFilter
      }), rewardedDatas && rewardedDatas.length ? React.createElement("div", {
        className: "reward-order-body ".concat(hasFilter ? 'has-filter' : 'no-filter')
      }, React.createElement(RewardedList, {
        rewardedData: rewardedDatas,
        goReward: goReward
      })) : React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Nodata, {
        icon: 1,
        text: "\u6682\u65E0\u5458\u5DE5\u83B7\u5F97\u6253\u8D4F"
      }), React.createElement(GoReward, {
        handleGoReward: goReward
      })));
    }
  }]);

  return RewardWrap;
}(React.Component);

export { RewardWrap as default };
